@@ -9,18 +9,18 @@
 
 #include <QTest>
 
-#include "kimaptest/fakeserver.h"
-#include "kimap/session.h"
 #include "kimap/listjob.h"
+#include "kimap/session.h"
+#include "kimaptest/fakeserver.h"
 
-#include <QTest>
-#include <QSignalSpy>
 #include <QDebug>
+#include <QSignalSpy>
+#include <QTest>
 
 Q_DECLARE_METATYPE(QList<KIMAP::MailBoxDescriptor>)
-Q_DECLARE_METATYPE(QList< QList<QByteArray> >)
+Q_DECLARE_METATYPE(QList<QList<QByteArray>>)
 
-class ListJobTest: public QObject
+class ListJobTest : public QObject
 {
     Q_OBJECT
 
@@ -29,12 +29,11 @@ private Q_SLOTS:
     void testList_data()
     {
         QTest::addColumn<bool>("unsubscribed");
-        QTest::addColumn<QList<QByteArray> >("scenario");
-        QTest::addColumn<QList<KIMAP::MailBoxDescriptor> >("listresult");
+        QTest::addColumn<QList<QByteArray>>("scenario");
+        QTest::addColumn<QList<KIMAP::MailBoxDescriptor>>("listresult");
 
         QList<QByteArray> scenario;
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LIST \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LIST \"\" *"
                  << "S: * LIST ( \\HasChildren ) / INBOX"
                  << "S: * LIST ( \\HasNoChildren ) / INBOX/&AOQ- &APY- &APw- @ &IKw-"
                  << "S: * LIST ( \\HasChildren ) / INBOX/lost+found"
@@ -59,8 +58,7 @@ private Q_SLOTS:
         QTest::newRow("normal") << true << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LIST \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LIST \"\" *"
                  << "S: * LIST ( \\HasChildren ) / Inbox"
                  << "S: * LIST ( \\HasNoChildren ) / Inbox/&AOQ- &APY- &APw- @ &IKw-"
                  << "S: * LIST ( \\HasChildren ) / Inbox/lost+found"
@@ -84,8 +82,7 @@ private Q_SLOTS:
         QTest::newRow("lowercase Inbox") << true << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LSUB \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LSUB \"\" *"
                  << "S: * LSUB ( \\HasChildren ) / INBOX"
                  << "S: * LSUB ( ) / INBOX/Calendar/3196"
                  << "S: * LSUB ( \\HasChildren ) / INBOX/Calendar/ff"
@@ -113,8 +110,7 @@ private Q_SLOTS:
         QTest::newRow("subscribed") << false << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LSUB \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LSUB \"\" *"
                  << "S: * LSUB ( \\HasChildren ) / Inbox"
                  << "S: * LSUB ( ) / Inbox/Calendar/3196"
                  << "S: * LSUB ( \\HasChildren ) / Inbox/Calendar/ff"
@@ -142,8 +138,7 @@ private Q_SLOTS:
         QTest::newRow("subscribed, lowercase Inbox") << false << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LIST \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LIST \"\" *"
                  << "S: * LIST ( \\HasNoChildren ) / INBOX/lost+found/Calendar Public-20080128"
                  << "S: A000001 OK LIST completed";
         listresult.clear();
@@ -154,8 +149,7 @@ private Q_SLOTS:
         QTest::newRow("unquoted-space") << true << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LIST \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LIST \"\" *"
                  << "S: * LIST ( \\NoInferiors ) ( ) INBOX"
                  << "S: A000001 OK LIST completed";
         listresult.clear();
@@ -166,15 +160,13 @@ private Q_SLOTS:
         QTest::newRow("separator is empty list") << true << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LIST \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LIST \"\" *"
                  << "S: A000001 BAD command unknown or arguments invalid";
         listresult.clear();
         QTest::newRow("bad") << true << scenario << listresult;
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 LIST \"\" *"
+        scenario << FakeServer::preauth() << "C: A000001 LIST \"\" *"
                  << "S: A000001 NO list failure";
         QTest::newRow("no") << true << scenario << listresult;
     }
@@ -191,34 +183,31 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        auto *job = new KIMAP::ListJob(&session);
+        auto job = new KIMAP::ListJob(&session);
         job->setIncludeUnsubscribed(unsubscribed);
 
-        QSignalSpy spy(job,
-                       SIGNAL(mailBoxesReceived(const QList<KIMAP::MailBoxDescriptor> &,
-                                                const QList< QList<QByteArray> > &)));
+        QSignalSpy spy(job, SIGNAL(mailBoxesReceived(const QList<KIMAP::MailBoxDescriptor> &, const QList<QList<QByteArray>> &)));
 
         bool result = job->exec();
-        QEXPECT_FAIL("bad" , "Expected failure on BAD response", Continue);
-        QEXPECT_FAIL("no" , "Expected failure on NO response", Continue);
+        QEXPECT_FAIL("bad", "Expected failure on BAD response", Continue);
+        QEXPECT_FAIL("no", "Expected failure on NO response", Continue);
         QVERIFY(result);
         if (result) {
             QVERIFY(spy.count() > 0);
             QList<KIMAP::MailBoxDescriptor> mailBoxes;
 
             for (int i = 0; i < spy.count(); ++i) {
-                mailBoxes += spy.at(i).at(0).value< QList<KIMAP::MailBoxDescriptor> >();
+                mailBoxes += spy.at(i).at(0).value<QList<KIMAP::MailBoxDescriptor>>();
             }
 
-            //qDebug() << mailBoxes.first().name;
-            //qDebug() << listresult.first().name;
+            // qDebug() << mailBoxes.first().name;
+            // qDebug() << listresult.first().name;
             QCOMPARE(mailBoxes, listresult);
         }
-//     QCOMPARE(job->mailBox(), mailbox);
+        //     QCOMPARE(job->mailBox(), mailbox);
 
         fakeServer.quit();
     }
-
 };
 
 QTEST_GUILESS_MAIN(ListJobTest)
